@@ -15,7 +15,7 @@ use namespace::autoclean;
 extends 'App::Sqitch::Command';
 with 'App::Sqitch::Role::RevertDeployCommand';
 
-our $VERSION = '0.996';
+our $VERSION = '0.997';
 
 has onto_change => (
     is  => 'ro',
@@ -61,7 +61,7 @@ sub configure {
 
 sub execute {
     my $self = shift;
-    my %args = $self->parse_args(@_);
+    my %args = $self->parse_args(target => $self->target, args => \@_);
 
     # Die on unknowns.
     if (my @unknown = @{ $args{unknown}} ) {
@@ -74,10 +74,10 @@ sub execute {
     }
 
     # Warn on multiple targets.
-    my $target = $self->target // shift @{ $args{targets} };
+    my $target = shift @{ $args{targets} };
     $self->warn(__x(
         'Too many targets specified; connecting to {target}',
-        target => $target,
+        target => $target->name,
     )) if @{ $args{targets} };
 
     # Warn on too many changes.
@@ -91,7 +91,7 @@ sub execute {
 
 
     # Now get to work.
-    my $engine = $self->engine_for_target($target);
+    my $engine = $target->engine;
     $engine->with_verify( $self->verify );
     $engine->no_prompt( $self->no_prompt );
     $engine->prompt_accept( $self->prompt_accept );
