@@ -5,17 +5,18 @@ use strict;
 use warnings;
 use utf8;
 use Moo;
-use Types::Standard qw(Str Int);
+use Types::Standard qw(Str Int HashRef);
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use URI::db;
 use Try::Tiny;
+use Path::Class qw(file dir);
 use List::Util qw(max);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
 
-our $VERSION = '0.996';
+our $VERSION = '0.997';
 
 has verbose => (
     is      => 'ro',
@@ -23,27 +24,48 @@ has verbose => (
     default => 0,
 );
 
-has registry => (
-    is  => 'ro',
-    isa => Str,
-);
-
-has client => (
-    is  => 'ro',
-    isa => Str,
+has properties => (
+    is      => 'ro',
+    isa     => HashRef,
+    default => sub { {} },
 );
 
 sub options {
     return qw(
+        set|s=s%
         registry|r=s
         client|c=s
         verbose|v+
     );
 }
 
+my %normalizer_for = (
+    top_dir   => sub { $_[0] ? dir($_[0])->cleanup : undef },
+    plan_file => sub { $_[0] ? file($_[0])->cleanup : undef },
+    client    => sub { $_[0] },
+);
+
+$normalizer_for{"$_\_dir"} = $normalizer_for{top_dir} for qw(deploy revert verify);
+$normalizer_for{$_} = $normalizer_for{client} for qw(registry extension);
+
 sub configure {
     my ( $class, $config, $options ) = @_;
 
+    # Handle deprecated options.
+    for my $key (qw(registry client)) {
+        my $val = delete $options->{$key} or next;
+        App::Sqitch->warn(__x(
+            'Option --{key} has been deprecated; use "--set {key}={val}" instead',
+            key => $key,
+            val => $val
+        ));
+        my $set = $options->{set} ||= {};
+        $set->{$key} = $val;
+    }
+
+    $options->{properties} = delete $options->{set}
+        if $options->{set};
+
     # No config; target config is actually targets.
     return $options;
 }
@@ -85,30 +107,26 @@ sub add {
         target => $name
     ) if $config->get( key => "$key.uri");
 
-    # Set the URI.
-    $config->set(
-        key      => "$key.uri",
-        value    => URI::db->new($uri, 'db:')->as_string,
-        filename => $config->local_file,
-    );
+    my @vars = ({
+        key   => "$key.uri",
+        value => URI::db->new($uri, 'db:')->as_string,
+    });
 
-    # Set the registry, if specified.
-    if (my $reg = $self->registry) {
-        $config->set(
-            key      => "$key.registry",
-            value    => $reg,
-            filename => $config->local_file,
-        );
+    # Collect properties.
+    my $props = $self->properties;
+    while (my ($prop, $val) = each %{ $props } ) {
+        my $normalizer = $normalizer_for{$prop} or $self->usage(__x(
+            'Unknown property "{property}"',
+            property => $prop,
+        ));
+        push @vars => {
+            key   => "$key.$prop",
+            value => $normalizer->($val),
+        };
     }
 
-    # Set the client, if specified.
-    if (my $reg = $self->client) {
-        $config->set(
-            key      => "$key.client",
-            value    => $reg,
-            filename => $config->local_file,
-        );
-    }
+    # Make it so.
+    $config->group_set( $config->local_file, \@vars );
 
     return $self;
 }
@@ -143,30 +161,64 @@ sub set_uri {
     );
 }
 
-sub set_registry {
-    shift->_set('registry', @_);
+sub set_registry  { shift->_set('registry',  @_) }
+sub set_client    { shift->_set('client',    @_) }
+sub set_extension { shift->_set('extension', @_) }
+
+sub _set_dir {
+    my ($self, $key, $name, $dir) = @_;
+    $self->_set( $key, $name, $normalizer_for{top_dir}->($dir) );
 }
 
-sub set_client {
-    shift->_set('client', @_);
+sub set_top_dir    { shift->_set_dir('top_dir',    @_) }
+sub set_deploy_dir { shift->_set_dir('deploy_dir', @_) }
+sub set_revert_dir { shift->_set_dir('revert_dir', @_) }
+sub set_verify_dir { shift->_set_dir('verify_dir', @_) }
+
+sub set_plan_file {
+    my ($self, $name, $file) = @_;
+    $self->_set( 'plan_file', $name, $normalizer_for{plan_file}->($file) );
 }
 
 sub rm { shift->remove(@_) }
 sub remove {
     my ($self, $name) = @_;
     $self->usage unless $name;
+    if ( my @deps = $self->_dependencies($name) ) {
+        hurl target => __x(
+            q{Cannot rename target "{target}" because it's refereneced by: {engines}},
+            target => $name,
+            engines => join ', ', @deps
+        );
+    }
     $self->_rename($name);
 }
 
 sub rename {
     my ($self, $old, $new) = @_;
     $self->usage unless $old && $new;
+    if ( my @deps = $self->_dependencies($old) ) {
+        hurl target => __x(
+            q{Cannot rename target "{target}" because it's refereneced by: {engines}},
+            target => $old,
+            engines => join ', ', @deps
+        );
+    }
     $self->_rename($old, $new);
 }
 
+sub _dependencies {
+    my ($self, $name) = @_;
+    my %depends = $self->sqitch->config->get_regexp(
+        key => qr/^(?:core|engine[.][^.]+)[.]target$/
+    );
+    return grep { $depends{$_} eq $name } sort keys %depends;
+}
+
 sub _rename {
     my ($self, $old, $new) = @_;
     my $config = $self->sqitch->config;
+
     try {
         $config->rename_section(
             from     => "target.$old",
@@ -186,27 +238,50 @@ sub _rename {
 sub show {
     my ($self, @names) = @_;
     return $self->list unless @names;
-    my $config = $self->sqitch->config;
+    my $sqitch = $self->sqitch;
+    my $config = $sqitch->config;
 
     # Set up labels.
     my $len = max map { length } (
         __ 'URI',
         __ 'Registry',
         __ 'Client',
+        __ 'Top Directory',
+        __ 'Plan File',
+        __ 'Deploy Directory',
+        __ 'Revert Directory',
+        __ 'Verify Directory',
+        __ 'Extension',
     );
 
     my %label_for = (
-        uri      => __('URI')      . ': ' . ' ' x ($len - length __ 'URI'),
-        registry => __('Registry') . ': ' . ' ' x ($len - length __ 'Registry'),
-        client   => __('Client')   . ': ' . ' ' x ($len - length __ 'Client'),
+        uri      => __('URI')                . ': ' . ' ' x ($len - length __ 'URI'),
+        registry => __('Registry')           . ': ' . ' ' x ($len - length __ 'Registry'),
+        client   => __('Client')             . ': ' . ' ' x ($len - length __ 'Client'),
+        top_dir    => __('Top Directory')    . ': ' . ' ' x ($len - length __ 'Top Directory'),
+        plan_file  => __('Plan File')        . ': ' . ' ' x ($len - length __ 'Plan File'),
+        deploy_dir => __('Deploy Directory') . ': ' . ' ' x ($len - length __ 'Deploy Directory'),
+        revert_dir => __('Revert Directory') . ': ' . ' ' x ($len - length __ 'Revert Directory'),
+        verify_dir => __('Verify Directory') . ': ' . ' ' x ($len - length __ 'Verify Directory'),
+        extension  => __('Extension')        . ': ' . ' ' x ($len - length __ 'Extension'),
     );
 
+    require App::Sqitch::Target;
     for my $name (@names) {
-        my $engine = $self->engine_for_target($name);
+        my $target = App::Sqitch::Target->new(
+            sqitch => $sqitch,
+            name   => $name,
+        );
         $self->emit("* $name");
-        $self->emit('  ', $label_for{uri},      $engine->uri->as_string);
-        $self->emit('  ', $label_for{registry}, $engine->registry);
-        $self->emit('  ', $label_for{client},   $engine->client);
+        $self->emit('  ', $label_for{uri},        $target->uri->as_string);
+        $self->emit('  ', $label_for{registry},   $target->registry);
+        $self->emit('  ', $label_for{client},     $target->client);
+        $self->emit('  ', $label_for{top_dir},    $target->top_dir);
+        $self->emit('  ', $label_for{plan_file},  $target->plan_file);
+        $self->emit('  ', $label_for{deploy_dir}, $target->deploy_dir);
+        $self->emit('  ', $label_for{revert_dir}, $target->revert_dir);
+        $self->emit('  ', $label_for{verify_dir}, $target->verify_dir);
+        $self->emit('  ', $label_for{extension},  $target->extension);
     }
 
     return $self;
@@ -235,13 +310,9 @@ Manages Sqitch targets, which are stored in the local configuration file.
 
 =head2 Attributes
 
-=head3 C<client>
+=head3 C<properties>
 
-Value to set the client attribute.
-
-=head3 C<registry>
-
-Value to set the registry attribute.
+Hash of property values to set.
 
 =head3 C<verbose>
 
@@ -285,6 +356,30 @@ Implements the C<set-registry> action.
 
 Implements the C<set-uri> action.
 
+=head3 C<set_top_dir>
+
+Implements the C<set-top-dir> action.
+
+=head3 C<set_plan_file>
+
+Implements the C<set-plan-file> action.
+
+=head3 C<set_deploy_dir>
+
+Implements the C<set-deploy-dir> action.
+
+=head3 C<set_revert_dir>
+
+Implements the C<set-revert-dir> action.
+
+=head3 C<set_verify_dir>
+
+Implements the C<set-verify-dir> action.
+
+=head3 C<set_extension>
+
+Implements the C<set-extension> action.
+
 =head3 C<show>
 
 Implements the C<show> action.
