@@ -15,28 +15,27 @@ use namespace::autoclean;
 
 extends 'App::Sqitch::Engine';
 
-our $VERSION = '0.996';
+our $VERSION = '0.997';
 
-has '+destination' => (
-    default  => sub {
-        my $self = shift;
+sub destination {
+    my $self = shift;
 
-        # Just use the target unless it looks like a URI.
-        my $target = $self->target;
-        return $target if $target !~ /:/;
+    # Just use the target name if it doesn't look like a URI or if the URI
+    # includes the database name.
+    return $self->target->name if $self->target->name !~ /:/
+        || $self->target->uri->dbname;
 
-        # Use the URI sans password, and with the database name added.
-        my $uri = $self->uri->clone;
-        $uri->password(undef) if $uri->password;
-        $uri->dbname(
-               $ENV{PGDATABASE}
-            || $uri->user
-            || $ENV{PGUSER}
-            || $self->sqitch->sysuser
-        ) unless $uri->dbname;
-        return $uri->as_string;
-    },
-);
+    # Use the URI sans password, and with the database name added.
+    my $uri = $self->target->uri->clone;
+    $uri->password(undef) if $uri->password;
+    $uri->dbname(
+        $ENV{PGDATABASE}
+        || $uri->user
+        || $ENV{PGUSER}
+        || $self->sqitch->sysuser
+    );
+    return $uri->as_string;
+}
 
 has _psql => (
     is         => 'ro',
@@ -74,7 +73,6 @@ sub _client_opts {
         '--tuples-only',
         '--set' => 'ON_ERROR_STOP=1',
         '--set' => 'registry=' . $self->registry,
-        '--set' => 'sqitch_schema=' . $self->registry, # deprecated
     );
 }
 
