@@ -3,17 +3,16 @@ package App::Sqitch::Plan::Blank;
 use 5.010;
 use utf8;
 use namespace::autoclean;
-use parent 'App::Sqitch::Plan::Line';
-use Mouse;
+use Moo;
+extends 'App::Sqitch::Plan::Line';
 
-our $VERSION = '0.995';
+our $VERSION = '0.997';
 
-has '+name' => ( default => '' );
+has '+name' => ( default => '', required => 0 );
 
 sub format_name { '' }
 
-__PACKAGE__->meta->make_immutable;
-no Mouse;
+1;
 
 __END__
 
