@@ -8,7 +8,7 @@ use App::Sqitch::Types qw(Str Plan);
 use App::Sqitch::X qw(hurl);
 use Locale::TextDomain qw(App-Sqitch);
 
-our $VERSION = '0.996';
+our $VERSION = '0.997';
 
 has name => (
     is       => 'ro',
@@ -57,7 +57,7 @@ has plan => (
     isa      => Plan,
     weak_ref => 1,
     required => 1,
-    handles  => [qw(sqitch project uri)],
+    handles  => [qw(sqitch project uri target)],
 );
 
 my %escape = (
